GoogleCloudDialogflowCxV3AdvancedSettings

Struct GoogleCloudDialogflowCxV3AdvancedSettings 

pub struct GoogleCloudDialogflowCxV3AdvancedSettings {
    pub audio_export_gcs_destination: Option<GoogleCloudDialogflowCxV3GcsDestination>,
    pub dtmf_settings: Option<GoogleCloudDialogflowCxV3AdvancedSettingsDtmfSettings>,
    pub logging_settings: Option<GoogleCloudDialogflowCxV3AdvancedSettingsLoggingSettings>,
    pub speech_settings: Option<GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings>,
}
Hierarchical advanced settings for agent/flow/page/fulfillment/parameter. Settings exposed at lower level overrides the settings exposed at higher level. Overriding occurs at the sub-setting level. For example, the playback_interruption_settings at fulfillment level only overrides the playback_interruption_settings at the agent level, leaving other settings at the agent level unchanged. DTMF settings does not override each other. DTMF settings set at different levels define DTMF detections running in parallel. Hierarchy: Agent->Flow->Page->Fulfillment/Parameter.

This type is not used in any activity, and only used as part of another schema.

Fields

audio_export_gcs_destination: Option<GoogleCloudDialogflowCxV3GcsDestination>

If present, incoming audio is exported by Dialogflow to the configured Google Cloud Storage destination. Exposed at the following levels: - Agent level - Flow level

dtmf_settings: Option<GoogleCloudDialogflowCxV3AdvancedSettingsDtmfSettings>

Settings for DTMF. Exposed at the following levels: - Agent level - Flow level - Page level - Parameter level.

logging_settings: Option<GoogleCloudDialogflowCxV3AdvancedSettingsLoggingSettings>

Settings for logging. Settings for Dialogflow History, Contact Center messages, StackDriver logs, and speech logging. Exposed at the following levels: - Agent level.

speech_settings: Option<GoogleCloudDialogflowCxV3AdvancedSettingsSpeechSettings>

Settings for speech to text detection. Exposed at the following levels: - Agent level - Flow level - Page level - Parameter level