pub struct GoogleCloudDialogflowCxV3AdvancedSettingsDtmfSettings {
pub enabled: Option<bool>,
pub endpointing_timeout_duration: Option<Duration>,
pub finish_digit: Option<String>,
pub interdigit_timeout_duration: Option<Duration>,
pub max_digits: Option<i32>,
}Expand description
Define behaviors for DTMF (dual tone multi frequency).
This type is not used in any activity, and only used as part of another schema.
Fields
enabled: Option<bool>If true, incoming audio is processed for DTMF (dual tone multi frequency) events. For example, if the caller presses a button on their telephone keypad and DTMF processing is enabled, Dialogflow will detect the event (e.g. a “3” was pressed) in the incoming audio and pass the event to the bot to drive business logic (e.g. when 3 is pressed, return the account balance).
endpointing_timeout_duration: Option<Duration>Endpoint timeout setting for matching dtmf input to regex.
finish_digit: Option<String>The digit that terminates a DTMF digit sequence.
interdigit_timeout_duration: Option<Duration>Interdigit timeout setting for matching dtmf input to regex.
max_digits: Option<i32>Max length of DTMF digits.