GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings

Struct GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings 

pub struct GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings {
    pub enable_answer_feedback: Option<bool>,
}
Settings for answer feedback collection.

This type is not used in any activity, and only used as part of another schema.

Fields

enable_answer_feedback: Option<bool>

Optional. If enabled, end users will be able to provide answer feedback to Dialogflow responses. Feature works only if interaction logging is enabled in the Dialogflow agent.