pub struct GoogleCloudDialogflowCxV3AgentPersonalizationSettings {
pub default_end_user_metadata: Option<HashMap<String, Value>>,
}Expand description
Settings for end user personalization.
This type is not used in any activity, and only used as part of another schema.
Fields
default_end_user_metadata: Option<HashMap<String, Value>>Optional. Default end user metadata, used when processing DetectIntent requests. Recommended to be filled as a template instead of hard-coded value, for example { “age”: “$session.params.age” }. The data will be merged with the QueryParameters.end_user_metadata in DetectIntentRequest.query_params during query processing.