pub struct GoogleCloudDialogflowCxV3AnswerFeedbackRatingReason {
pub feedback: Option<String>,
pub reason_labels: Option<Vec<String>>,
}Expand description
Stores extra information about why users provided thumbs down rating.
This type is not used in any activity, and only used as part of another schema.
Fields
feedback: Option<String>Optional. Additional feedback about the rating. This field can be populated without choosing a predefined reason.
reason_labels: Option<Vec<String>>Optional. Custom reason labels for thumbs down rating provided by the user. The maximum number of labels allowed is 10 and the maximum length of a single label is 128 characters.