pub struct GoogleCloudDialogflowCxV3BoostSpec {
pub condition_boost_specs: Option<Vec<GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpec>>,
}Expand description
Boost specification to boost certain documents. A copy of google.cloud.discoveryengine.v1main.BoostSpec, field documentation is available at https://cloud.google.com/generative-ai-app-builder/docs/reference/rest/v1alpha/BoostSpec
This type is not used in any activity, and only used as part of another schema.
Fields
condition_boost_specs: Option<Vec<GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpec>>Optional. Condition boost specifications. If a document matches multiple conditions in the specifictions, boost scores from these specifications are all applied and combined in a non-linear way. Maximum number of specifications is 20.