pub struct GoogleCloudDialogflowCxV3ConversationTurn {
pub user_input: Option<GoogleCloudDialogflowCxV3ConversationTurnUserInput>,
pub virtual_agent_output: Option<GoogleCloudDialogflowCxV3ConversationTurnVirtualAgentOutput>,
}Expand description
One interaction between a human and virtual agent. The human provides some input and the virtual agent provides a response.
This type is not used in any activity, and only used as part of another schema.
Fields
user_input: Option<GoogleCloudDialogflowCxV3ConversationTurnUserInput>The user input.
virtual_agent_output: Option<GoogleCloudDialogflowCxV3ConversationTurnVirtualAgentOutput>The virtual agent output.