GoogleCloudDialogflowCxV3ConversationTurnUserInput

Struct GoogleCloudDialogflowCxV3ConversationTurnUserInput 

pub struct GoogleCloudDialogflowCxV3ConversationTurnUserInput {
    pub enable_sentiment_analysis: Option<bool>,
    pub injected_parameters: Option<HashMap<String, Value>>,
    pub input: Option<GoogleCloudDialogflowCxV3QueryInput>,
    pub is_webhook_enabled: Option<bool>,
}
The input from the human user.

This type is not used in any activity, and only used as part of another schema.

Fields

enable_sentiment_analysis: Option<bool>

Whether sentiment analysis is enabled.

injected_parameters: Option<HashMap<String, Value>>

Parameters that need to be injected into the conversation during intent detection.

input: Option<GoogleCloudDialogflowCxV3QueryInput>

Supports text input, event input, dtmf input in the test case.

is_webhook_enabled: Option<bool>

If webhooks should be allowed to trigger in response to the user utterance. Often if parameters are injected, webhooks should not be enabled.