pub struct GoogleCloudDialogflowCxV3ConversationTurnVirtualAgentOutput {
pub current_page: Option<GoogleCloudDialogflowCxV3Page>,
pub diagnostic_info: Option<HashMap<String, Value>>,
pub differences: Option<Vec<GoogleCloudDialogflowCxV3TestRunDifference>>,
pub session_parameters: Option<HashMap<String, Value>>,
pub status: Option<GoogleRpcStatus>,
pub text_responses: Option<Vec<GoogleCloudDialogflowCxV3ResponseMessageText>>,
pub triggered_intent: Option<GoogleCloudDialogflowCxV3Intent>,
}Expand description
The output from the virtual agent.
This type is not used in any activity, and only used as part of another schema.
Fields
current_page: Option<GoogleCloudDialogflowCxV3Page>The Page on which the utterance was spoken. Only name and displayName will be set.
diagnostic_info: Option<HashMap<String, Value>>Required. Input only. The diagnostic info output for the turn. Required to calculate the testing coverage.
differences: Option<Vec<GoogleCloudDialogflowCxV3TestRunDifference>>Output only. If this is part of a result conversation turn, the list of differences between the original run and the replay for this output, if any.
session_parameters: Option<HashMap<String, Value>>The session parameters available to the bot at this point.
status: Option<GoogleRpcStatus>Response error from the agent in the test result. If set, other output is empty.
text_responses: Option<Vec<GoogleCloudDialogflowCxV3ResponseMessageText>>The text responses from the agent for the turn.
triggered_intent: Option<GoogleCloudDialogflowCxV3Intent>The Intent that triggered the response. Only name and displayName will be set.