pub struct GoogleCloudDialogflowCxV3DeploymentResult {
pub deployment_test_results: Option<Vec<String>>,
pub experiment: Option<String>,
}Expand description
Result of the deployment.
This type is not used in any activity, and only used as part of another schema.
Fields
deployment_test_results: Option<Vec<String>>Results of test cases running before the deployment. Format: projects//locations//agents//testCases//results/.
experiment: Option<String>The name of the experiment triggered by this deployment. Format: projects//locations//agents//environments//experiments/.