pub struct GoogleCloudDialogflowCxV3EntityTypeExcludedPhrase {
pub value: Option<String>,
}Expand description
An excluded entity phrase that should not be matched.
This type is not used in any activity, and only used as part of another schema.
Fields
value: Option<String>Required. The word or phrase to be excluded.