pub struct GoogleCloudDialogflowCxV3EnvironmentTestCasesConfig {
pub enable_continuous_run: Option<bool>,
pub enable_predeployment_run: Option<bool>,
pub test_cases: Option<Vec<String>>,
}Expand description
The configuration for continuous tests.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_continuous_run: Option<bool>Whether to run test cases in TestCasesConfig.test_cases periodically. Default false. If set to true, run once a day.
enable_predeployment_run: Option<bool>Whether to run test cases in TestCasesConfig.test_cases before deploying a flow version to the environment. Default false.
test_cases: Option<Vec<String>>A list of test case names to run. They should be under the same agent. Format of each test case name: projects//locations/ /agents//testCases/