pub struct GoogleCloudDialogflowCxV3ExperimentDefinition {
pub condition: Option<String>,
pub version_variants: Option<GoogleCloudDialogflowCxV3VersionVariants>,
}Expand description
Definition of the experiment.
This type is not used in any activity, and only used as part of another schema.
Fields
condition: Option<String>The condition defines which subset of sessions are selected for this experiment. If not specified, all sessions are eligible. E.g. “query_input.language_code=en” See the conditions reference.
version_variants: Option<GoogleCloudDialogflowCxV3VersionVariants>The flow versions as the variants of this experiment.