pub struct GoogleCloudDialogflowCxV3ExperimentResult {
pub last_update_time: Option<DateTime<Utc>>,
pub version_metrics: Option<Vec<GoogleCloudDialogflowCxV3ExperimentResultVersionMetrics>>,
}Expand description
The inference result which includes an objective metric to optimize and the confidence interval.
This type is not used in any activity, and only used as part of another schema.
Fields
last_update_time: Option<DateTime<Utc>>The last time the experiment’s stats data was updated. Will have default value if stats have never been computed for this experiment.
version_metrics: Option<Vec<GoogleCloudDialogflowCxV3ExperimentResultVersionMetrics>>Version variants and metrics.