pub struct GoogleCloudDialogflowCxV3Form {
pub parameters: Option<Vec<GoogleCloudDialogflowCxV3FormParameter>>,
}Expand description
A form is a data model that groups related parameters that can be collected from the user. The process in which the agent prompts the user and collects parameter values from the user is called form filling. A form can be added to a page. When form filling is done, the filled parameters will be written to the session.
This type is not used in any activity, and only used as part of another schema.
Fields
parameters: Option<Vec<GoogleCloudDialogflowCxV3FormParameter>>Parameters to collect from the user.