pub struct GoogleCloudDialogflowCxV3FormParameter {
pub advanced_settings: Option<GoogleCloudDialogflowCxV3AdvancedSettings>,
pub default_value: Option<Value>,
pub display_name: Option<String>,
pub entity_type: Option<String>,
pub fill_behavior: Option<GoogleCloudDialogflowCxV3FormParameterFillBehavior>,
pub is_list: Option<bool>,
pub redact: Option<bool>,
pub required: Option<bool>,
}Expand description
Represents a form parameter.
This type is not used in any activity, and only used as part of another schema.
Fields
advanced_settings: Option<GoogleCloudDialogflowCxV3AdvancedSettings>Hierarchical advanced settings for this parameter. The settings exposed at the lower level overrides the settings exposed at the higher level.
default_value: Option<Value>The default value of an optional parameter. If the parameter is required, the default value will be ignored.
display_name: Option<String>Required. The human-readable name of the parameter, unique within the form.
entity_type: Option<String>Required. The entity type of the parameter. Format: projects/-/locations/-/agents/-/entityTypes/ for system entity types (for example, projects/-/locations/-/agents/-/entityTypes/sys.date), or projects//locations//agents//entityTypes/ for developer entity types.
fill_behavior: Option<GoogleCloudDialogflowCxV3FormParameterFillBehavior>Required. Defines fill behavior for the parameter.
is_list: Option<bool>Indicates whether the parameter represents a list of values.
redact: Option<bool>Indicates whether the parameter content should be redacted in log. If redaction is enabled, the parameter content will be replaced by parameter name during logging. Note: the parameter content is subject to redaction if either parameter level redaction or entity type level redaction is enabled.
required: Option<bool>Indicates whether the parameter is required. Optional parameters will not trigger prompts; however, they are filled if the user specifies them. Required parameters must be filled before form filling concludes.