pub struct GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase {
pub case_content: Option<Vec<GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent>>,
pub condition: Option<String>,
}Expand description
Each case has a Boolean condition. When it is evaluated to be True, the corresponding messages will be selected and evaluated recursively.
This type is not used in any activity, and only used as part of another schema.
Fields
case_content: Option<Vec<GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent>>A list of case content.
condition: Option<String>The condition to activate and select this case. Empty means the condition is always true. The condition is evaluated against form parameters or session parameters. See the conditions reference.