pub struct GoogleCloudDialogflowCxV3GcsDestination {
pub uri: Option<String>,
}Expand description
Google Cloud Storage location for a Dialogflow operation that writes or exports objects (e.g. exported agent or transcripts) outside of Dialogflow.
This type is not used in any activity, and only used as part of another schema.
Fields
uri: Option<String>Required. The Google Cloud Storage URI for the exported objects. A URI is of the form: gs://bucket/object-name-or-prefix Whether a full object name, or just a prefix, its usage depends on the Dialogflow operation.