pub struct GoogleCloudDialogflowCxV3GenerativeSettingsFallbackSettingsPromptTemplate {
pub display_name: Option<String>,
pub frozen: Option<bool>,
pub prompt_text: Option<String>,
}Expand description
Prompt template.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>Prompt name.
frozen: Option<bool>If the flag is true, the prompt is frozen and cannot be modified by users.
prompt_text: Option<String>Prompt text that is sent to a LLM on no-match default, placeholders are filled downstream. For example: “Here is a conversation $conversation, a response is: “