pub struct GoogleCloudDialogflowCxV3GenerativeSettingsKnowledgeConnectorSettings {
pub agent: Option<String>,
pub agent_identity: Option<String>,
pub agent_scope: Option<String>,
pub business: Option<String>,
pub business_description: Option<String>,
pub disable_data_store_fallback: Option<bool>,
}Expand description
Settings for knowledge connector. These parameters are used for LLM prompt like “You are . You are a helpful and verbose at , . Your task is to help humans on “.
This type is not used in any activity, and only used as part of another schema.
Fields
agent: Option<String>Name of the virtual agent. Used for LLM prompt. Can be left empty.
agent_identity: Option<String>Identity of the agent, e.g. “virtual agent”, “AI assistant”.
agent_scope: Option<String>Agent scope, e.g. “Example company website”, “internal Example company website for employees”, “manual of car owner”.
business: Option<String>Name of the company, organization or other entity that the agent represents. Used for knowledge connector LLM prompt and for knowledge search.
business_description: Option<String>Company description, used for LLM prompt, e.g. “a family company selling freshly roasted coffee beans”.
disable_data_store_fallback: Option<bool>Whether to disable fallback to Data Store search results (in case the LLM couldn’t pick a proper answer). Per default the feature is enabled.