pub struct GoogleCloudDialogflowCxV3GeneratorPlaceholder {
pub id: Option<String>,
pub name: Option<String>,
}Expand description
Represents a custom placeholder in the prompt text.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>Unique ID used to map custom placeholder to parameters in fulfillment.
name: Option<String>Custom placeholder value in the prompt text.