pub struct GoogleCloudDialogflowCxV3InlineSource {
pub content: Option<Vec<u8>>,
}Expand description
Inline source for a Dialogflow operation that reads or imports objects (e.g. intents) into Dialogflow.
This type is not used in any activity, and only used as part of another schema.
Fields
content: Option<Vec<u8>>The uncompressed byte content for the objects.