pub struct GoogleCloudDialogflowCxV3IntentParameter {
pub entity_type: Option<String>,
pub id: Option<String>,
pub is_list: Option<bool>,
pub redact: Option<bool>,
}Expand description
Represents an intent parameter.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_type: Option<String>Required. The entity type of the parameter. Format: projects/-/locations/-/agents/-/entityTypes/ for system entity types (for example, projects/-/locations/-/agents/-/entityTypes/sys.date), or projects//locations//agents//entityTypes/ for developer entity types.
id: Option<String>Required. The unique identifier of the parameter. This field is used by training phrases to annotate their parts.
is_list: Option<bool>Indicates whether the parameter represents a list of values.
redact: Option<bool>Indicates whether the parameter content should be redacted in log. If redaction is enabled, the parameter content will be replaced by parameter name during logging. Note: the parameter content is subject to redaction if either parameter level redaction or entity type level redaction is enabled.