pub struct GoogleCloudDialogflowCxV3IntentTrainingPhrasePart {
pub parameter_id: Option<String>,
pub text: Option<String>,
}Expand description
Represents a part of a training phrase.
This type is not used in any activity, and only used as part of another schema.
Fields
parameter_id: Option<String>The parameter used to annotate this part of the training phrase. This field is required for annotated parts of the training phrase.
text: Option<String>Required. The text for this part.