GoogleCloudDialogflowCxV3KnowledgeConnectorSettings

Struct GoogleCloudDialogflowCxV3KnowledgeConnectorSettings 

pub struct GoogleCloudDialogflowCxV3KnowledgeConnectorSettings {
    pub data_store_connections: Option<Vec<GoogleCloudDialogflowCxV3DataStoreConnection>>,
    pub enabled: Option<bool>,
    pub target_flow: Option<String>,
    pub target_page: Option<String>,
    pub trigger_fulfillment: Option<GoogleCloudDialogflowCxV3Fulfillment>,
}
The Knowledge Connector settings for this page or flow. This includes information such as the attached Knowledge Bases, and the way to execute fulfillment.

This type is not used in any activity, and only used as part of another schema.

Fields

data_store_connections: Option<Vec<GoogleCloudDialogflowCxV3DataStoreConnection>>

Optional. List of related data store connections.

enabled: Option<bool>

Whether Knowledge Connector is enabled or not.

target_flow: Option<String>

The target flow to transition to. Format: projects//locations//agents//flows/.

target_page: Option<String>

The target page to transition to. Format: projects//locations//agents//flows//pages/.

trigger_fulfillment: Option<GoogleCloudDialogflowCxV3Fulfillment>

The fulfillment to be triggered. When the answers from the Knowledge Connector are selected by Dialogflow, you can utitlize the request scoped parameter $request.knowledge.answers (contains up to the 5 highest confidence answers) and $request.knowledge.questions (contains the corresponding questions) to construct the fulfillment.