pub struct GoogleCloudDialogflowCxV3ListContinuousTestResultsResponse {
pub continuous_test_results: Option<Vec<GoogleCloudDialogflowCxV3ContinuousTestResult>>,
pub next_page_token: Option<String>,
}Expand description
The response message for Environments.ListTestCaseResults.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
continuous_test_results: Option<Vec<GoogleCloudDialogflowCxV3ContinuousTestResult>>The list of continuous test results.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.