pub struct GoogleCloudDialogflowCxV3ListExperimentsResponse {
pub experiments: Option<Vec<GoogleCloudDialogflowCxV3Experiment>>,
pub next_page_token: Option<String>,
}Expand description
The response message for Experiments.ListExperiments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
experiments: Option<Vec<GoogleCloudDialogflowCxV3Experiment>>The list of experiments. There will be a maximum number of items returned based on the page_size field in the request. The list may in some cases be empty or contain fewer entries than page_size even if this isn’t the last page.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.