GoogleCloudDialogflowCxV3Match

Struct GoogleCloudDialogflowCxV3Match 

pub struct GoogleCloudDialogflowCxV3Match {
    pub confidence: Option<f32>,
    pub event: Option<String>,
    pub intent: Option<GoogleCloudDialogflowCxV3Intent>,
    pub match_type: Option<String>,
    pub parameters: Option<HashMap<String, Value>>,
    pub resolved_input: Option<String>,
}
Represents one match result of MatchIntent.

This type is not used in any activity, and only used as part of another schema.

Fields

confidence: Option<f32>

The confidence of this match. Values range from 0.0 (completely uncertain) to 1.0 (completely certain). This value is for informational purpose only and is only used to help match the best intent within the classification threshold. This value may change for the same end-user expression at any time due to a model retraining or change in implementation.

event: Option<String>

The event that matched the query. Filled for EVENT, NO_MATCH and NO_INPUT match types.

intent: Option<GoogleCloudDialogflowCxV3Intent>

The Intent that matched the query. Some, not all fields are filled in this message, including but not limited to: name and display_name. Only filled for INTENT match type.

match_type: Option<String>

Type of this Match.

parameters: Option<HashMap<String, Value>>

The collection of parameters extracted from the query. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: * MapKey type: string * MapKey value: parameter name * MapValue type: If parameter’s entity type is a composite entity then use map, otherwise, depending on the parameter value type, it could be one of string, number, boolean, null, list or map. * MapValue value: If parameter’s entity type is a composite entity then use map from composite entity property names to property values, otherwise, use parameter value.

resolved_input: Option<String>

Final text input which was matched during MatchIntent. This value can be different from original input sent in request because of spelling correction or other processing.