pub struct GoogleCloudDialogflowCxV3NluSettings {
pub classification_threshold: Option<f32>,
pub model_training_mode: Option<String>,
pub model_type: Option<String>,
}Expand description
Settings related to NLU.
This type is not used in any activity, and only used as part of another schema.
Fields
classification_threshold: Option<f32>To filter out false positive results and still get variety in matched natural language inputs for your agent, you can tune the machine learning classification threshold. If the returned score value is less than the threshold value, then a no-match event will be triggered. The score values range from 0.0 (completely uncertain) to 1.0 (completely certain). If set to 0.0, the default of 0.3 is used.
model_training_mode: Option<String>Indicates NLU model training mode.
model_type: Option<String>Indicates the type of NLU model.