pub struct GoogleCloudDialogflowCxV3ResponseMessageEndInteraction { /* private fields */ }Expand description
Indicates that interaction with the Dialogflow agent has ended. This message is generated by Dialogflow only and not supposed to be defined by the user.
This type is not used in any activity, and only used as part of another schema.