pub struct GoogleCloudDialogflowCxV3ResponseMessageKnowledgeInfoCard { /* private fields */ }Expand description
Represents info card response. If the response contains generative knowledge prediction, Dialogflow will return a payload with Infobot Messenger compatible info card. Otherwise, the info card response is skipped.
This type is not used in any activity, and only used as part of another schema.