GoogleCloudDialogflowCxV3ResponseMessageMixedAudio

Struct GoogleCloudDialogflowCxV3ResponseMessageMixedAudio 

pub struct GoogleCloudDialogflowCxV3ResponseMessageMixedAudio {
    pub segments: Option<Vec<GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment>>,
}
Represents an audio message that is composed of both segments synthesized from the Dialogflow agent prompts and ones hosted externally at the specified URIs. The external URIs are specified via play_audio. This message is generated by Dialogflow only and not supposed to be defined by the user.

This type is not used in any activity, and only used as part of another schema.

Fields

segments: Option<Vec<GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment>>

Segments this audio response is composed of.