pub struct GoogleCloudDialogflowCxV3RolloutConfig {
pub failure_condition: Option<String>,
pub rollout_condition: Option<String>,
pub rollout_steps: Option<Vec<GoogleCloudDialogflowCxV3RolloutConfigRolloutStep>>,
}Expand description
The configuration for auto rollout.
This type is not used in any activity, and only used as part of another schema.
Fields
failure_condition: Option<String>The conditions that are used to evaluate the failure of a rollout step. If not specified, no rollout steps will fail. E.g. “containment_rate < 10% OR average_turn_count < 3”. See the conditions reference.
rollout_condition: Option<String>The conditions that are used to evaluate the success of a rollout step. If not specified, all rollout steps will proceed to the next one unless failure conditions are met. E.g. “containment_rate > 60% AND callback_rate < 20%”. See the conditions reference.
rollout_steps: Option<Vec<GoogleCloudDialogflowCxV3RolloutConfigRolloutStep>>Steps to roll out a flow version. Steps should be sorted by percentage in ascending order.