pub struct GoogleCloudDialogflowCxV3RolloutConfigRolloutStep {
pub display_name: Option<String>,
pub min_duration: Option<Duration>,
pub traffic_percent: Option<i32>,
}Expand description
A single rollout step with specified traffic allocation.
This type is not used in any activity, and only used as part of another schema.
Fields
display_name: Option<String>The name of the rollout step;
min_duration: Option<Duration>The minimum time that this step should last. Should be longer than 1 hour. If not set, the default minimum duration for each step will be 1 hour.
traffic_percent: Option<i32>The percentage of traffic allocated to the flow version of this rollout step. (0%, 100%].