pub struct GoogleCloudDialogflowCxV3RolloutState {
pub start_time: Option<DateTime<Utc>>,
pub step: Option<String>,
pub step_index: Option<i32>,
}Expand description
State of the auto-rollout process.
This type is not used in any activity, and only used as part of another schema.
Fields
start_time: Option<DateTime<Utc>>Start time of the current step.
step: Option<String>Display name of the current auto rollout step.
step_index: Option<i32>Index of the current step in the auto rollout steps list.