GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings

Struct GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings 

pub struct GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings {
    pub audio_export_pattern: Option<String>,
    pub audio_format: Option<String>,
    pub enable_audio_redaction: Option<bool>,
    pub gcs_bucket: Option<String>,
    pub store_tts_audio: Option<bool>,
}
Settings for exporting audio.

This type is not used in any activity, and only used as part of another schema.

Fields

audio_export_pattern: Option<String>

Filename pattern for exported audio.

audio_format: Option<String>

File format for exported audio file. Currently only in telephony recordings.

enable_audio_redaction: Option<bool>

Enable audio redaction if it is true. Note that this only redacts end-user audio data; Synthesised audio from the virtual agent is not redacted.

gcs_bucket: Option<String>

Cloud Storage bucket to export audio record to. Setting this field would grant the Storage Object Creator role to the Dialogflow Service Agent. API caller that tries to modify this field should have the permission of storage.buckets.setIamPolicy.

store_tts_audio: Option<bool>

Whether to store TTS audio. By default, TTS audio from the virtual agent is not exported.