pub struct GoogleCloudDialogflowCxV3SentimentAnalysisResult {
pub magnitude: Option<f32>,
pub score: Option<f32>,
}Expand description
The result of sentiment analysis. Sentiment analysis inspects user input and identifies the prevailing subjective opinion, especially to determine a user’s attitude as positive, negative, or neutral.
This type is not used in any activity, and only used as part of another schema.
Fields
magnitude: Option<f32>A non-negative number in the [0, +inf) range, which represents the absolute magnitude of sentiment, regardless of score (positive or negative).
score: Option<f32>Sentiment score between -1.0 (negative sentiment) and 1.0 (positive sentiment).