pub struct GoogleCloudDialogflowCxV3TextToSpeechSettings {
pub synthesize_speech_configs: Option<HashMap<String, GoogleCloudDialogflowCxV3SynthesizeSpeechConfig>>,
}Expand description
Settings related to speech synthesizing.
This type is not used in any activity, and only used as part of another schema.
Fields
synthesize_speech_configs: Option<HashMap<String, GoogleCloudDialogflowCxV3SynthesizeSpeechConfig>>Configuration of how speech should be synthesized, mapping from language (https://cloud.google.com/dialogflow/cx/docs/reference/language) to SynthesizeSpeechConfig. These settings affect: - The phone gateway synthesize configuration set via Agent.text_to_speech_settings. - How speech is synthesized when invoking session APIs. Agent.text_to_speech_settings only applies if OutputAudioConfig.synthesize_speech_config is not specified.