pub struct GoogleCloudDialogflowCxV3VoiceSelectionParams {
pub name: Option<String>,
pub ssml_gender: Option<String>,
}Expand description
Description of which voice to use for speech synthesis.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Optional. The name of the voice. If not set, the service will choose a voice based on the other parameters such as language_code and ssml_gender. For the list of available voices, please refer to Supported voices and languages.
ssml_gender: Option<String>Optional. The preferred gender of the voice. If not set, the service will choose a voice based on the other parameters such as language_code and name. Note that this is only a preference, not requirement. If a voice of the appropriate gender is not available, the synthesizer substitutes a voice with a different gender rather than failing the request.