pub struct GoogleCloudDialogflowCxV3BoostSpecConditionBoostSpec {
pub boost: Option<f32>,
pub condition: Option<String>,
}Expand description
Boost applies to documents which match a condition.
This type is not used in any activity, and only used as part of another schema.
Fields
boost: Option<f32>Optional. Strength of the condition boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0. Setting to 1.0 gives the document a big promotion. However, it does not necessarily mean that the boosted document will be the top result at all times, nor that other documents will be excluded. Results could still be shown even when none of them matches the condition. And results that are significantly more relevant to the search query can still trump your heavily favored but irrelevant documents. Setting to -1.0 gives the document a big demotion. However, results that are deeply relevant might still be shown. The document will have an upstream battle to get a fairly high ranking, but it is not blocked out completely. Setting to 0.0 means no boost applied. The boosting condition is ignored.
condition: Option<String>Optional. An expression which specifies a boost condition. The syntax and supported fields are the same as a filter expression. Examples: * To boost documents with document ID “doc_1” or “doc_2”, and color “Red” or “Blue”: * (id: ANY(“doc_1”, “doc_2”)) AND (color: ANY(“Red”,“Blue”))