pub struct GoogleCloudDialogflowCxV3ResponseMessage {
pub channel: Option<String>,
pub conversation_success: Option<GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess>,
pub end_interaction: Option<GoogleCloudDialogflowCxV3ResponseMessageEndInteraction>,
pub knowledge_info_card: Option<GoogleCloudDialogflowCxV3ResponseMessageKnowledgeInfoCard>,
pub live_agent_handoff: Option<GoogleCloudDialogflowCxV3ResponseMessageLiveAgentHandoff>,
pub mixed_audio: Option<GoogleCloudDialogflowCxV3ResponseMessageMixedAudio>,
pub output_audio_text: Option<GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText>,
pub payload: Option<HashMap<String, Value>>,
pub play_audio: Option<GoogleCloudDialogflowCxV3ResponseMessagePlayAudio>,
pub response_type: Option<String>,
pub telephony_transfer_call: Option<GoogleCloudDialogflowCxV3ResponseMessageTelephonyTransferCall>,
pub text: Option<GoogleCloudDialogflowCxV3ResponseMessageText>,
}Expand description
Represents a response message that can be returned by a conversational agent. Response messages are also used for output audio synthesis. The approach is as follows: * If at least one OutputAudioText response is present, then all OutputAudioText responses are linearly concatenated, and the result is used for output audio synthesis. * If the OutputAudioText responses are a mixture of text and SSML, then the concatenated result is treated as SSML; otherwise, the result is treated as either text or SSML as appropriate. The agent designer should ideally use either text or SSML consistently throughout the bot design. * Otherwise, all Text responses are linearly concatenated, and the result is used for output audio synthesis. This approach allows for more sophisticated user experience scenarios, where the text displayed to the user may differ from what is heard.
This type is not used in any activity, and only used as part of another schema.
Fields
channel: Option<String>The channel which the response is associated with. Clients can specify the channel via QueryParameters.channel, and only associated channel response will be returned.
conversation_success: Option<GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess>Indicates that the conversation succeeded.
end_interaction: Option<GoogleCloudDialogflowCxV3ResponseMessageEndInteraction>Output only. A signal that indicates the interaction with the Dialogflow agent has ended. This message is generated by Dialogflow only when the conversation reaches END_SESSION page. It is not supposed to be defined by the user. It’s guaranteed that there is at most one such message in each response.
knowledge_info_card: Option<GoogleCloudDialogflowCxV3ResponseMessageKnowledgeInfoCard>Represents info card for knowledge answers, to be better rendered in Dialogflow Messenger.
live_agent_handoff: Option<GoogleCloudDialogflowCxV3ResponseMessageLiveAgentHandoff>Hands off conversation to a human agent.
mixed_audio: Option<GoogleCloudDialogflowCxV3ResponseMessageMixedAudio>Output only. An audio response message composed of both the synthesized Dialogflow agent responses and responses defined via play_audio. This message is generated by Dialogflow only and not supposed to be defined by the user.
output_audio_text: Option<GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText>A text or ssml response that is preferentially used for TTS output audio synthesis, as described in the comment on the ResponseMessage message.
payload: Option<HashMap<String, Value>>Returns a response containing a custom, platform-specific payload.
play_audio: Option<GoogleCloudDialogflowCxV3ResponseMessagePlayAudio>Signal that the client should play an audio clip hosted at a client-specific URI. Dialogflow uses this to construct mixed_audio. However, Dialogflow itself does not try to read or process the URI in any way.
response_type: Option<String>Response type.
telephony_transfer_call: Option<GoogleCloudDialogflowCxV3ResponseMessageTelephonyTransferCall>A signal that the client should transfer the phone call connected to this agent to a third-party endpoint.
text: Option<GoogleCloudDialogflowCxV3ResponseMessageText>Returns a text response.