pub struct GoogleCloudDialogflowCxV3ResponseMessagePlayAudio {
pub allow_playback_interruption: Option<bool>,
pub audio_uri: Option<String>,
}Expand description
Specifies an audio clip to be played by the client as part of the response.
This type is not used in any activity, and only used as part of another schema.
Fields
allow_playback_interruption: Option<bool>Output only. Whether the playback of this message can be interrupted by the end user’s speech and the client can then starts the next Dialogflow request.
audio_uri: Option<String>Required. URI of the audio clip. Dialogflow does not impose any validation on this value. It is specific to the client that reads it.